2023 Atomic Weights
Description: The full text of the IUPAC table of atomic weights
Keywords: IUPAC atomic weight relative atomic mass

IUPAC Commission on Isotopic Abundances and Atomic Weights.

# ATOMIC WEIGHTS OF THE ELEMENTS 2023

These tables are based on the 2021 table with changes from the 2019 table for the values of Ar, Hf, Ir, Pb and Yb and changes to the uncertainty for Al, Au, Co, F, Ho, Mn, Nb, Pa, Pr, Rh, Sc, Tb, Tm, and Y. The values of Gd, Lu and Zr were revised and published in 2024.

https://iupac.qmul.ac.uk/AtWt/

World Wide Web version of atomic weight data originally prepared by G. P. Moss, from a file provided by D. R. Lide.

Previous values may be consulted from the 1993 table, the 1995 table, the 1997 table, the 1999 table, the 2001 table, the 2005 table, the 2007 table, the 2009 table, the 2011 table, the 2013 table, the 2015 table, 2019 table or the 2021 table.

The standard atomic weights of twelve elements having two or more stable isotopes have variability of atomic-weight values in natural terrestrial materials. These are given in table 1 below. In the other lists the values quoted are those suggested for material where the origin of the sample is unknown. For radioactive elements the isotope with the longest half-life is quoted in parenthesis. The original paper should be consulted for full details of the variation in atomic weight and the half life of the radioisotopes quoted below.

A number in parentheses indicates the uncertainty in the last digit of the atomic weight.

See below for the elements listed in Atomic Number Order or Name order.

See also a copy of the periodic table with atomic weights to five significant figures.

### Table 1. List of Elements with Range of Atomic Weights.

At No | Symbol | Name | Minimum Atomic Wt | Maximum Atomic Wt
1 | H | hydrogen | 1.007 84 | 1.008 11
3 | Li | lithium | 6.938 | 6.997
5 | B | boron | 10.806 | 10.821
6 | C | carbon | 12.0096 | 12.0116
7 | N | nitrogen | 14.006 43 | 14.007 28
8 | O | oxygen | 15.999 03 | 15.999 77
12 | Mg | magnesium | 24.304 | 24.307
14 | Si | silicon | 28.084 | 28.086
16 | S | sulfur | 32.059 | 32.076
17 | Cl | chlorine | 35.446 | 35.457
18 | Ar | argon | 39.792 | 39.963
35 | Br | bromine | 79.901 | 79.907
81 | Tl | thallium | 204.382 | 204.385
82 | Pb | lead | 206.14 | 207.94

See original paper for the range of these elements from different sources [Isotope-abundance variations and atomic weights of selected elements: 2016 (IUPAC Technical Report), Pure Appl. Chem. 2016, 88(12), 1203-1224., Pure Appl. Chem. 2021, 93(1), 155-166 and Pure Appl. Chem. 2022, 94]

### Table 2. List of Elements in Atomic Number Order.

At No | Symbol | Name | Atomic Wt | Notes
1 | H | Hydrogen | 1.0080(2) | 3, 5
2 | He | Helium | 4.002 602(2) | 1, 2
3 | Li | Lithium | 6.94(6) | 3, 5
4 | Be | Beryllium | 9.012 1831(5)
5 | B | Boron | 10.81(2) | 3, 5
6 | C | Carbon | 12.011(2) | 5
7 | N | Nitrogen | 14.007(1) | 5
8 | O | Oxygen | 15.999(1) | 5
9 | F | Fluorine | 18.998 403 162(5)
10 | Ne | Neon | 20.1797(6) | 1, 3
11 | Na | Sodium | 22.989 769 28(2)
12 | Mg | Magnesium | 24.305(2) | 5
13 | Al | Aluminium | 26.981 5384(3)
14 | Si | Silicon | 28.085(1) | 5
15 | P | Phosphorus | (30.973 761 998(5)
16 | S | Sulfur | 32.06(2) | 5
17 | Cl | Chlorine | 35.45(1) | 3, 5
18 | Ar | Argon | 39.95(16) | 1, 2, 5
19 | K | Potassium | 39.0983(1) |
20 | Ca | Calcium | 40.078(4) |
21 | Sc | Scandium | 44.955 907(4)
22 | Ti | Titanium | 47.867(1)
23 | V | Vanadium | 50.9415(1)
24 | Cr | Chromium | 51.9961(6)
25 | Mn | Manganese | 54.938 043(2)
26 | Fe | Iron | 55.845(2)
27 | Co | Cobalt | 58.933 194(3)
28 | Ni | Nickel | 58.6934(4) | 2
29 | Cu | Copper | 63.546(3) | 2
30 | Zn | Zinc | 65.38(2) | 2
31 | Ga | Gallium | 69.723(1)
32 | Ge | Germanium | 72.630(8)
33 | As | Arsenic | 74.921 595(6)
34 | Se | Selenium | 78.971(8)
35 | Br | Bromine | 79.904(3)_ | 5
36 | Kr | Krypton | 83.798(2) | 1, 3
37 | Rb | Rubidium | 85.4678(3) | 1
38 | Sr | Strontium | 87.62(1) | 1, 2
39 | Y | Yttrium | 88.905 838(2)
40 | Zr | Zirconium | 91.222(3) | 1
41 | Nb | Niobium | 92.906 37(1)
42 | Mo | Molybdenum | 95.95(1) | 1
43 | Tc | Technetium | [97] | 4
44 | Ru | Ruthenium | 101.07(2) | 1
45 | Rh | Rhodium | 102.905 49(2)
46 | Pd | Palladium | 106.42(1) | 1
47 | Ag | Silver | 107.8682(2) | 1
48 | Cd | Cadmium | 112.414(4) | 1
49 | In | Indium | 114.818(1)
50 | Sn | Tin | 118.710(7) | 1
51 | Sb | Antimony | 121.760(1) | 1
52 | Te | Tellurium | 127.60(3) | 1
53 | I | Iodine | 126.904 47(3)
54 | Xe | Xenon | 131.293(6) | 1, 3
55 | Cs | Caesium | 132.905 451 96(6)
56 | Ba | Barium | 137.327(7)
57 | La | Lanthanum | 138.905 47(7) | 1
58 | Ce | Cerium | 140.116(1) | 1
59 | Pr | Praseodymium | 140.907 66(1)
60 | Nd | Neodymium | 144.242(3) | 1
61 | Pm | Promethium | [145] |
62 | Sm | Samarium | 150.36(2) | 1
63 | Eu | Europium | 151.964(1) | 1
64 | Gd | Gadolinium | 157.249(2) | 1
65 | Tb | Terbium | 158.925 354(7)
66 | Dy | Dysprosium | 162.500(1) | 1
67 | Ho | Holmium | 164.930 329(5)
68 | Er | Erbium | 167.259(3) | 1
69 | Tm | Thulium | 168.934 219(5)
70 | Yb | Ytterbium | 173.045(10) | 1
71 | Lu | Lutetium | 174.966 69(5) | 1
72 | Hf | Hafnium | 178.486(6)
73 | Ta | Tantalum | 180.947 88(2)
74 | W | Tungsten | 183.84(1)
75 | Re | Rhenium | 186.207(1)
76 | Os | Osmium | 190.23(3) | 1
77 | Ir | Iridium | 192.217(2)
78 | Pt | Platinum | 195.084(9)
79 | Au | Gold | 196.966 570(4)
80 | Hg | Mercury | 200.592(3)
81 | Tl | Thallium | 204.38(1) | 5
82 | Pb | Lead | 207.2(1.1) | 1, 2, 5
83 | Bi | Bismuth | 208.980 40(1)
84 | Po | Polonium | [209] | 4
85 | At | Astatine | [210] | 4
86 | Rn | Radon | [222] | 4
87 | Fr | Francium | [223] | 4
88 | Ra | Radium | [226] | 4
89 | Ac | Actinium | [227] | 4
90 | Th | Thorium | 232.0377(4) | 1, 4
91 | Pa | Protactinium | 231.035 88(1) | 4
92 | U | Uranium | 238.028 91(3) | 1, 3, 4
93 | Np | Neptunium | [237] | 4
94 | Pu | Plutonium | [244] | 4
95 | Am | Americium | [243] | 4
96 | Cm | Curium | [247] | 4
97 | Bk | Berkelium | [247] | 4
98 | Cf | Californium | [251] | 4
99 | Es | Einsteinium | [252] | 4
100 | Fm | Fermium | [257] | 4
101 | Md | Mendelevium | [258] | 4
102 | No | Nobelium | [259] | 4
103 | Lr | Lawrencium | [262] | 4
104 | Rf | Rutherfordium | [267] | 4
105 | Db | Dubnium | [270] | 4
106 | Sg | Seaborgium | [269] | 4
107 | Bh | Bohrium | [270] | 4
108 | Hs | Hassium | [270] | 4
109 | Mt | Meitnerium | [278] | 4
110 | Ds | Darmstadtium | [281] | 4
111 | Rg | Roentgenium | [281] | 4
112 | Cn | Copernicium | [285] | 4
113 | Nh | Nihonium | [286] | 4
114 | Fl | Flerovium | [289] | 4
115 | Mc | Moscovium | [289] | 4
116 | Lv | Livermorium | [293] | 4
117 | Ts | Tennessine | [293] | 4
118 | Og | Oganesson | [294] | 4

1. Geological specimens are known in which the element has an isotopic composition outside the limits for normal material. The difference between the atomic weight of the element in such specimens and that given in the Table may exceed the stated uncertainty.
2. Range in isotopic composition of normal terrestrial material prevents a more precise value being given; the tabulated value should be applicable to any normal material.
3. Modified isotopic compositions may be found in commercially available material because it has been subject to an undisclosed or inadvertant isotopic fractionation. Substantial deviations in atomic weight of the element from that given in the Table can occur.
4. Element has no stable nuclides. The value enclosed in brackets, e.g. [209], indicates the mass number of the longest-lived isotope of the element. However three such elements (Th, Pa, and U) do have a characteristic terrestrial isotopic composition, and for these an atomic weight is tabulated.
5. See table 1 for details of range and original paper for the atomic weight of the element from different sources.

### Table 3. List of Elements in Name Order.

At No | Symbol | Name | Atomic Wt | Notes
89 | Ac | Actinium | [227] | 4
13 | Al | Aluminium | 26.981 5384(3)
95 | Am | Americium | [243] | 4
51 | Sb | Antimony | 121.760(1) | 1
18 | Ar | Argon | 39.95(16) | 1, 2, 5
33 | As | Arsenic | 74.921 595(6)
85 | At | Astatine | [210] | 4
56 | Ba | Barium | 137.327(7)
97 | Bk | Berkelium | [247] | 4
4 | Be | Beryllium | 9.012 1831(5)
83 | Bi | Bismuth | 208.980 40(1)
107 | Bh | Bohrium | [270] | 4
5 | B | Boron | 10.81(2) | 3, 5
35 | Br | Bromine | 79.904(3) | 5
48 | Cd | Cadmium | 112.414(4) | 1
55 | Cs | Caesium | 132.905 451 96(6)
20 | Ca | Calcium | 40.078(4) | 1
98 | Cf | Californium | [251] | 4
6 | C | Carbon | 12.011(2) | 5
58 | Ce | Cerium | 140.116(1) | 1
17 | Cl | Chlorine | 35.45 | 3, 5
24 | Cr | Chromium | 51.9961(6)
27 | Co | Cobalt | 58.933 194(3)
112 | Cn | Copernicium | [285] | 4
29 | Cu | Copper | 63.546(3) | 2
96 | Cm | Curium | [247] | 4
110 | Ds | Darmstadtium | [281] | 4
105 | Db | Dubnium | [270] | 4
66 | Dy | Dysprosium | 162.500(1) | 1
99 | Es | Einsteinium | [252] | 4
68 | Er | Erbium | 167.259(3) | 1
63 | Eu | Europium | 151.964(1) | 1
100 | Fm | Fermium | [257] | 4
114 | Fl | Flerovium | [289] | 4
9 | F | Fluorine | 18.998 403 162(5)
87 | Fr | Francium | [223] | 4
64 | Gd | Gadolinium | 157.249(2) | 1
31 | Ga | Gallium | 69.723(1)
32 | Ge | Germanium | 72.630(8)
79 | Au | Gold | 196.966 570(4)
72 | Hf | Hafnium | 178.486(6)
108 | Hs | Hassium | [270] | 4
2 | He | Helium | 4.002 602(2) | 1, 2
67 | Ho | Holmium | 164.930 329(5)
1 | H | Hydrogen | 1.008 | 3, 5
49 | In | Indium | 114.818(1)
53 | I | Iodine | 126.904 47(3)
77 | Ir | Iridium | 192.217(2)
26 | Fe | Iron | 55.845(2)
36 | Kr | Krypton | 83.798(2) | 1, 3
57 | La | Lanthanum | 138.905 47(7) | 1
103 | Lr | Lawrencium | [262] | 4
82 | Pb | Lead | 207.2(1.1) | 1, 2, 5
3 | Li | Lithium | 6.94 | 3, 5
116 | Lv | Livermorium | [293] | 4
71 | Lu | Lutetium | 174.966 69(5) | 1
12 | Mg | Magnesium | 24.305(2) | 5
25 | Mn | Manganese | 54.938 043(2)
109 | Mt | Meitnerium | [278] | 4
101 | Md | Mendelevium | [258] | 4
80 | Hg | Mercury | 200.592(3)
42 | Mo | Molybdenum | 95.95(1) | 1
115 | Mc | Moscovium | [289] | 4
60 | Nd | Neodymium | 144.242(3) | 1
10 | Ne | Neon | 20.1797(6) | 1, 3
93 | Np | Neptunium | [237] | 4
28 | Ni | Nickel | 58.6934(4)
113 | Nh | Nihonium | [286] | 4
41 | Nb | Niobium | 92.906 37(1)
7 | N | Nitrogen | 14.007(1) | 5
102 | No | Nobelium | [259] | 4
118 | Og | Oganesson | [294] | 4
76 | Os | Osmium | 190.23(3) | 1
8 | O | Oxygen | 15.999(1) | 5
46 | Pd | Palladium | 106.42(1) | 1
15 | P | Phosphorus | 30.973 761 998(5)
78 | Pt | Platinum | 195.084(9)
94 | Pu | Plutonium | [244] | 4
84 | Po | Polonium | [209] | 4
19 | K | Potassium | 39.0983(1) |
59 | Pr | Praseodymium | 140.907 66(1)
61 | Pm | Promethium | [145] | 4
91 | Pa | Protactinium | 231.035 88(1) | 4
88 | Ra | Radium | [226] | 4
86 | Rn | Radon | [222] | 4
75 | Re | Rhenium | 186.207(1)
45 | Rh | Rhodium | 102.905 49(2)
111 | Rg | Roentgenium | [281] | 4
37 | Rb | Rubidium | 85.4678(3) | 1
44 | Ru | Ruthenium | 101.07(2) | 1
104 | Rf | Rutherfordium | [267] | 4
62 | Sm | Samarium | 150.36(2) | 1
21 | Sc | Scandium | 44.955 907(4)
106 | Sg | Seaborgium | [269] | 4
34 | Se | Selenium | 78.971(8)
14 | Si | Silicon | 28.085(1) | 5
47 | Ag | Silver | 107.8682(2) | 1
11 | Na | Sodium | 22.989 769 28(2)
38 | Sr | Strontium | 87.62(1) | 1, 2
16 | S | Sulfur | 32.06(2) | 5
73 | Ta | Tantalum | 180.947 88(2)
43 | Tc | Technetium | [97] | 4
52 | Te | Tellurium | 127.60(3) | 1
117 | Ts | Tennessine | [293] | 4
65 | Tb | Terbium | 158.925 354(7)
81 | Tl | Thallium | 204.38(1) | 5
90 | Th | Thorium | 232.0377(4) | 1, 4
69 | Tm | Thulium | 168.934 219(5)
50 | Sn | Tin | 118.710(7) | 1
22 | Ti | Titanium | 47.867(1)
74 | W | Tungsten | 183.84(1)
92 | U | Uranium | 238.028 91(3) | 1, 3, 4
23 | V | Vanadium | 50.9415(1)
54 | Xe | Xenon | 131.293(6) | 1, 3
70 | Yb | Ytterbium | 173.045(10) | 1
39 | Y | Yttrium | 88.905 838(2)
30 | Zn | Zinc | 65.38(2) | 2
40 | Zr | Zirconium | 91.222(3) | 1

1. Geological specimens are known in which the element has an isotopic composition outside the limits for normal material. The difference between the atomic weight of the element in such specimens and that given in the Table may exceed the stated uncertainty.
2. Range in isotopic composition of normal terrestrial material prevents a more precise value being given; the tabulated value should be applicable to any normal material.
3. Modified isotopic compositions may be found in commercially available material because it has been subject to an undisclosed or inadvertent isotopic fractionation. Substantial deviations in atomic weight of the element from that given in the Table can occur.
4. Element has no stable nuclides. The value enclosed in brackets, e.g. [209], indicates the mass number of the longest-lived isotope of the element. However three such elements (Th, Pa, and U) do have a characteristic terrestrial isotopic composition, and for these an atomic weight is tabulated.
5. See table 1 for details of range and original paper for the atomic weight of the element from different sources.

Return to IUPAC Chemical Nomenclature home page